#
# spec file for package systemtap
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if ! %{defined _rundir}
%define _rundir %{_localstatedir}/run
%endif
Name:           systemtap
Version:        5.1
Release:        2.1
Summary:        Instrumentation System
License:        GPL-2.0-or-later
Group:          Development/Tools/Debuggers
URL:            https://sourceware.org/systemtap/
Source0:        https://sourceware.org/systemtap/ftp/releases/systemtap-%{version}.tar.gz
Source1:        https://sourceware.org/systemtap/ftp/releases/systemtap-%{version}.tar.gz.asc
Source2:        %{name}.keyring
Source3:        README-BEFORE-ADDING-PATCHES
Source4:        README-KEYRING
Source5:        stap-server.conf
Patch1:         systemtap-build-source-dir.patch

BuildRequires:  autoconf >= 2.71
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libavahi-devel
BuildRequires:  libcap-devel
BuildRequires:  libdw-devel
BuildRequires:  mozilla-nspr-devel
BuildRequires:  mozilla-nss-devel
BuildRequires:  mozilla-nss-tools
BuildRequires:  pkgconfig
BuildRequires:  python3-base
BuildRequires:  sqlite-devel
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(libdebuginfod)
BuildRequires:  pkgconfig(systemd)
Requires:       %{name}-dtrace = %{version}
Requires:       %{name}-runtime = %{version}-%{release}
Recommends:     kernel-devel
Obsoletes:      systemtap-client < 1.5

%description
SystemTap is an instrumentation system for systems running Linux.
Developers can write instrumentation to collect data on the operation
of the system.

%package runtime
Summary:        Runtime environment for systemtap
Group:          Development/Tools/Debuggers

%description runtime
SystemTap is an instrumentation system for systems running Linux.
This package contains the runtime environment for systemtap programs.

%package server
Summary:        Systemtap server
Group:          Development/Tools/Debuggers
Requires:       %{name} = %{version}-%{release}
# dependancies for systemtap shell scripts
Requires:       avahi
Requires:       avahi-utils
Requires:       coreutils
Requires:       mozilla-nss-tools
Requires:       unzip
Requires:       zip

%description server
SystemTap is an instrumentation system for systems running Linux.
This package contains the server component of systemtap.

%package sdt-devel
Summary:        Static probe support tools
# systemtap-headers provides the same header files
# as sdt-devel, so we must conflict.
Group:          Development/Tools/Debuggers
Requires:       %{name} = %{version}-%{release}
Conflicts:      systemtap-headers

%description sdt-devel
SystemTap is an instrumentation system for systems running Linux.
This package contains the support tools for static probes.

%prep
%setup -q
%autopatch -p1

%build
autoreconf -fi
%configure \
  --disable-docs \
  --with-python3 \
  --docdir=%{_docdir}/systemtap
make %{?_smp_mflags} V=1

%install
%make_install
rm -f %{buildroot}%{_bindir}/dtrace
rm -f %{buildroot}%{_libexecdir}/systemtap/stap-server-request
# README, AUTHORS, NEWS, man3 and all examples packaged by systemtap-docs
# COPYING needs to stay in main for GPL
rm -rf %{buildroot}%{_docdir}/systemtap/
rm -rf %{buildroot}%{_datadir}/systemtap/examples
rm -rf %{buildroot}%{_mandir}/man3 %{buildroot}%{_mandir}/cs/man3
mkdir -p %{buildroot}%{_docdir}/systemtap/
cp COPYING %{buildroot}%{_docdir}/systemtap/
mkdir -p %{buildroot}%{_localstatedir}/cache/systemtap
mkdir -p %{buildroot}%{_localstatedir}/log
touch %{buildroot}%{_localstatedir}/log/stap-server.log
# config file for stap-server (/run now on tmpfs)
mkdir -p %{buildroot}%{_tmpfilesdir}
install -m 644 %{SOURCE5} %{buildroot}%{_tmpfilesdir}

%fdupes %{buildroot}%{_datadir}/%{name}
%python3_fix_shebang

%find_lang systemtap

%post server
# Create tmpfiles
%tmpfiles_create %{_tmpfilesdir}/stap-server.conf

%files
%{_bindir}/stap
%{_bindir}/stap-profile-annotate
%{_bindir}/stap-jupyter-container
%{_bindir}/stap-jupyter-install
%{_mandir}/man[17]/*
%{_mandir}/cs/man[17]/*
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/runtime
%{_datadir}/%{name}/interactive-notebook
%{_datadir}/%{name}/tapset
#packaged by systemtap-initscript in upstream
%dir %{_localstatedir}/cache/systemtap

%files runtime -f systemtap.lang
%doc %{_docdir}/systemtap
%{_bindir}/staprun
%{_bindir}/stapsh
%{_bindir}/stap-merge
%{_bindir}/stap-report
%{_bindir}/stapbpf
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/stapio
%{_libexecdir}/%{name}/stap-env
%{_libexecdir}/%{name}/stap-authorize-cert
%{_mandir}/man8/staprun.8*
%{_mandir}/man8/systemtap-service.8*
%{_mandir}/cs/man8/systemtap.8*
%{_mandir}/man8/stapsh.8*
%{_mandir}/cs/man8/stapsh.8*
%{_mandir}/man8/stapbpf.8*

%files server
%dir %{_tmpfilesdir}
%{_tmpfilesdir}/stap-server.conf
%{_bindir}/stap-server
%{_libexecdir}/%{name}/stap-gen-cert
%{_libexecdir}/%{name}/stap-serverd
%{_libexecdir}/%{name}/stap-sign-module
%{_libexecdir}/%{name}/stap-start-server
%{_libexecdir}/%{name}/stap-stop-server
%{_mandir}/man8/stap-server.8*
%{_mandir}/cs/man8/stap-server.8*
%ghost %{_localstatedir}/log/stap-server.log
%ghost %dir %{_rundir}/stap-server

%files sdt-devel
%{_includedir}/sys/*.h

%changelog
* Mon Jun 17 2024 Tony Jones <tonyj@suse.com>
- Update to version 5.1
  Summary of changes:
  * SystemTap frontend (stap) changes
  - An experimental "--build-as=USER" flag to reduce privilege during
    script compilation, which is a security improvement effort.
  - New probe-points for userland hardware breakpoints/watchpoints
    targeting processes (PR31180):
    probe process.data(ADDRESS).write
    probe process.data(ADDRESS).rw
    probe process.data(ADDRESS).length(LEN).write
    probe process.data(ADDRESS).length(LEN).rw
  - Support for stap --remote=bpf.
  - Improved searching heuristics for probing symbol names with/without
    symbol-version suffixes and with/without weak names.
  - Made long-running debuginfod downloads more cleanly interruptible.
  - Improved stap-prep heuristics for finding debuginfo for "-rt"
    (real-time) kernels.
  * SystemTap backend changes
  - Dynamic namespace switching for processes targeted via "-x PID",
    allowing processes running within containers to be probed.
  - Improved message transport robustness for heavy traffic (individual
    messages spanning pages) and for short runs (avoiding loss of
    last-gasp messages).
  - Added MTAG macro on several internal memory allocation routines
    to improve leak warnings.  Corrected a bunch of leaks.
  - "stap -t" now reports module initialization timings too.
  - Ported runtime for GCC14 compatibility, with its more recent C
    dialect warnings.
  - Support for DW_OP_bra in DWARF location lists, which makes a few
    more $context variables accessible to systemtap.
  * SystemTap tapset changes
  - Portability fixes for more recent kernels, as always.
  - set_kernel_string* tapset functions improved range checking.
  - print_ubacktrace_fileline() works with PIE binaries.
  - Many portability improvements and some fixes in the testsuite.
  - Enhancements for the tcp, nfs, memory tapsets.
  Drop following patches (upstream):
  - bpf-translate.cxx-fix-build-against-upcoming-gcc14.patch
  - get-shm_flag-defines-from-the-appropriate-include-file-for-linux-6.8-kernel.patch
  - pr31288-build-with-gcc14-cont.patch
  - pr31288-build-with-gcc14.patch
  - pr31373-deal-with-the-removal-of-strlcpy-from-linux-6.8.patch
  - staprun-fix-build-against-upcoming-gcc14.patch
  - stapvirt.c-more-gcc-14-werror-calloc-transposed-args-compatibility.patch
* Tue Apr  2 2024 Tony Jones <tonyj@suse.com>
- Fix runtime issues with v6.8 kernel (bsc#1222249)
    New patch: get-shm_flag-defines-from-the-appropriate-include-file-for-linux-6.8-kernel.patch
    New patch: pr31373-deal-with-the-removal-of-strlcpy-from-linux-6.8.patch
* Thu Mar 28 2024 Tony Jones <tonyj@suse.com>
- Fix gcc14 build errors (bsc#1221706)
    New patch: bpf-translate.cxx-fix-build-against-upcoming-gcc14.patch
    New patch: pr31288-build-with-gcc14-cont.patch
    New patch: pr31288-build-with-gcc14.patch
    New patch: staprun-fix-build-against-upcoming-gcc14.patch
    New patch: stapvirt.c-more-gcc-14-werror-calloc-transposed-args-compatibility.patch
* Fri Mar  8 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang macro, [bsc#1212476]
* Sat Dec 30 2023 Florian "sp1rit" <sp1rit@disroot.org>
- Upgrade to version 5.0:
  * Performance improvements in uprobe registration and module startup.
  * More probe point process details are printed in "-L" list mode with
    more "-v".
  * For the case where newer kernels may break systemtap runtime APIs,
    better pass-4 failure diagnostics are printed.
  * Tapset function print_ubacktrace_fileline() now understands DWARF5.
  * The target(s) of process probes may be specified by path name
    globs, as located selected debuginfod servers.  This requires the
    debuginfod servers to support "metadata" queries.  The following
    probes all of the binaries matching /usr/*/curl known to the
    debuginfod servers, regardless of what's currently installed as the
    system /usr/bin/curl:
    [#] export DEBUGINFOD_URLS="URL1 URL2 ..."
    [#] stap -e 'probe debuginfod.process("/usr/*/curl").begin { log("hi") }'
    The archive glob may be given as an optional component to filter further:
    [#] stap -e 'probe debuginfod.archive("*.fc38*")
    .process("/usr/*/c*").function("main") { log("Hello World") }'
  * The kernel-user message transport system added framing codes,
    making the transport more reliable, but becoming incompatible
    across pre-5.0 versions.  Use matching versions of stap and
    staprun.
  * RHEL6, kernel 2.6.32* as well as older releases have been
    deprecated from the codebase.  RHEL7 and kernel version 3.10 are
    now the oldest supported versions for Systemtap.
  * The testsuite Makefile has been simplified to remove concurrency,
    so "parallel" and "resume" modes are gone.
  * New runtime macro STP_TIMING_NSECS is now supported for reporting
    probe timing stats in nsecs instead of cycles.  This may become
    default later.
  * Add new runtime macro STP_FORCE_STDOUT_TTY to override
    STP_STDOUT_NOT_ATTY.
* Wed May 10 2023 Dirk Müller <dmueller@suse.com>
- update to 4.9:
  * ISystemtap: the new interactive systemtap jupyter kernel.
    This provides a simple GUI for writing/running Systemtap
    scripts in an easy, incremental way within Jupyterlab.
    Added 2 news scripts, stap-jupyter-install
    and stap-jupyter-container. See stap-jupyter(1).
  * The new "language-server" mode, specified by "stap
  - -language-server", starts a LSP server which will
    communicate with the client via stdio.
  * This server currently supports code completion suggestions.
  * See language-server/README.md for more details and usage
    instructions.
  * Safety/liveness checking for $context variable assignments in
    probes of retpoline-compiled kernels is temporarily disabled.
  * DWARF-related probes (.function, .statement) now merge DWARF
    and non-DWARF symbol-table based matches, rather than being
    either-or.
  * The python3 tapset was extended to support python3 3.9, 3.10,
    and 3.11. See stapprobes(3stap) for further details on probing
    python functions.
  * A template cve band-aid script is now included, which
    demonstrates how to use a new 'livepatch.stp' tapset to
    standardize activation, interactive control,
    and monitoring of systemtap cve band-aids.
  * The kernel runtime now uses much less memory when the number
    of "possible CPUs" are way more than the online ones. For
    example, VMWare guests usually have 128 "possible CPUs" while fewer
    CPUs are actually present or online in the guest system.
  * The memory allocation size is now irrelevant to the value of
    NR_CPUS of the current kernel. It is only subject to the
    number of "possible CPUs" or "online CPUs".
  * CPU hotplug is supported to the extent that there won't be
    any kernel panics or memory corruptions.
  * The bpf backend's embedded-code assembler has been improved
    to support more conventional assembly syntax with named
    opcodes. The opcode names are based on the iovisor bpf-docs
    documentation at
    https://github.com/iovisor/bpf-docs/blob/master/eBPF.md
* Thu May  4 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add _multibuild to define 2nd spec file as additional flavor.
  Eliminates the need for source package links in OBS.
* Tue Sep 13 2022 Tony Jones <tonyj@suse.com>
- Update to version 4.7
  Release notes: https://sourceware.org/pipermail/systemtap/2022q2/027491.html
- Remove patches (upstream):
    Handle-user-supplied-sdt-probe-argument-template.patch
    PR28778-gcc-warning-tweak-for-sprintf-precision-parameter.patch
    buildrun-for-LKM-backend-add-Wno-infinite-recursion.patch
    gcc12-c-compatibility-re-tweak-for-rhel6-use-function-pointer-instead-of-lambdas-instead-of-ptr_fun.patch
    gcc12-c-compatibility-tweak-use-lambdas-instead-of-ptr_fun.patch
    gcc12-warning-suppression.patch
    sys-sdt.h-fp-constraints-aarch64-s390.patch
    sys-sdt.h-fp-constraints-arm32.patch
    sys-sdt.h-fp-constraints-x86_64.patch
- Update systemtap.keyring
* Wed Mar  2 2022 Tony Jones <tonyj@suse.com>
- Add gcc12 support (bsc#1196583)
    New patch: PR28778-gcc-warning-tweak-for-sprintf-precision-parameter.patch
    New patch: gcc12-c-compatibility-tweak-use-lambdas-instead-of-ptr_fun.patch
    New patch: gcc12-c-compatibility-re-tweak-for-rhel6-use-function-pointer-instead-of-lambdas-instead-of-ptr_fun.patch
    New patch: buildrun-for-LKM-backend-add-Wno-infinite-recursion.patch
    New patch: gcc12-warning-suppression.patch
* Mon Feb 21 2022 Andreas Schwab <schwab@suse.de>
- Handle-user-supplied-sdt-probe-argument-template.patch: Fix glibc build
  failure on s390x
* Mon Feb 14 2022 Tony Jones <tonyj@suse.com>
- Resolve gcc compilation error reported against glib2 and libvirt
    New patch: sys-sdt.h-fp-constraints-arm32.patch
    New patch: sys-sdt.h-fp-constraints-x86_64.patch
    New patch: sys-sdt.h-fp-constraints-aarch64-s390.patch
* Thu Jan 27 2022 Tony Jones <tonyj@suse.com>
- Update to version 4.6 (bsc#1194395)
  4.6 release notes: https://sourceware.org/pipermail/systemtap/2021q4/027370.html
  4.5 release notes: https://sourceware.org/pipermail/systemtap/2021q2/027225.html
  4.4 release notes: https://sourceware.org/pipermail/systemtap/2020q4/027074.html
  4.3 release notes: https://sourceware.org/pipermail/systemtap/2020q2/026923.html
  Remove patches (upstream):
  - systemtap-amend-fallback-comment-to-work-with-newer-gcc.patch
  - systemtap-fix-strict-prototypes-in-autoconf-stack-trace-save-regs.c.patch
  Update systemtap.keyring for new signer
* Wed Apr 28 2021 Tony Jones <tonyj@suse.com>
- Adjust stap-server.conf to refer to /run not /var/run (bsc#1185068)
* Mon Aug 24 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%{_tmpfilesdir} instead of wrong %%{_libexecdir}/tmpfiles.d
  that just coincidentally happened to match (boo#1174075).
* Thu Feb  6 2020 Tony Jones <tonyj@suse.com>
- Add recommends on kernel-devel (bsc#1158733)
* Mon Feb  3 2020 Tony Jones <tonyj@suse.com>
- Resolve protoype issue when invoking tracebacks (bsc#1161296)
  Also dependent fix to handle GCC fallthrough
  New patch: systemtap-fix-strict-prototypes-in-autoconf-stack-trace-save-regs.c.patch
  New patch: systemtap-amend-fallback-comment-to-work-with-newer-gcc.patch
* Mon Jan 27 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Replace libebl-devel BuildRequires with libdw-devel: ebl is
  being absorbed by libdw.
* Fri Dec  6 2019 Tony Jones <tonyj@suse.com>
- Update to version 4.2
  Release notes: https://sourceware.org/ml/systemtap/2019-q4/msg00044.html
  Delete patch: systemtap-support-wimplicit-fallthrough-vsprintf.patch
  Delete patch: systemtap-support-wimplicit-fallthrough-gen_map.patch
* Thu Nov  7 2019 Tony Jones <tonyj@suse.com>
- Add support for gcc -Wimplicit-fallthrough to resolve compilation errors
    of the form "this statement may fall through"
  New patch: systemtap-support-wimplicit-fallthrough-vsprintf.patch
  New patch: systemtap-support-wimplicit-fallthrough-gen_map.patch
* Mon Oct 14 2019 Martin Pluskal <mpluskal@suse.com>
- Do not require exact version of systemtap-dtrace as build
  counters are not same for different packages
* Mon Sep 30 2019 Michael Gorse <mgorse@suse.com>
- Moved the dtrace binary into a separate package to resolve build
  cycle with glib2 (bsc#1145438).
* Fri Aug  9 2019 Tony Jones <tonyj@suse.com>
- Update to version 4.1.
  Do not package systemtap-exporter.
  4.1 release notes: https://sourceware.org/ml/systemtap/2019-q2/msg00043.html
  4.0 release notes: https://sourceware.org/ml/systemtap/2018-q4/msg00018.html
- Force autoreconf of configure to match systemtap-docs (tarball configure
  is stale).
* Mon Apr 15 2019 jlee@suse.com
- Add BuildRequire libavahi-devel, otherwise that the systemstap-server
  and systemstap client do not work. (bsc#1132538)
* Wed Jan 30 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow to use
  systemd-mini during build.
- Use %%tmpfiles_create macro in -server package: consider the right
  usage in transactional update cases.
* Fri Jan  4 2019 mgorse@suse.com
- Remove glib2-devel from BuildRequires: it appears not to be used
  and causes a build loop if glib2 is built with SDT markers
  (bsc#1090047).
* Fri Aug  3 2018 sschricker@suse.de
- Upgrade to version 3.3:
  Changelog: https://lwn.net/Articles/757030/
  eBPF backend extensions, easier access to examples, adapting to
  meltdown/spectre complications, real-time / high-cpu-count
  concurrency fixes
- Remove patches, because the issues were fixed upstream:
    systemtap-fixes-for-gcc-8.patch
    systemtap-change-extra_cflags-escape-processing.patch
- Adjust patch for version 3.3:
    systemtap-build-source-dir.patch
- Added public key of "Frank Ch. Eigler <fche@elastic.org>",
  since he signed the new package
* Fri Mar 23 2018 tonyj@suse.com
- GCC 8 fixes (bsc#1084642)
  New patch: systemtap-fixes-for-gcc-8.patch
* Fri Feb 16 2018 matz@suse.com
- Care for pecularities of build counter syncs between different
  build rings: the Requires from sdt-devel can't use %%release
  for systemtap-headers, but we also don't want to just include
  %%version, so separate both totally:
  * Add the include headers to sdt-devel again.
  * Add Conflicts with systemtap-headers to care for the resulting
    file conflicts.
  * Remove Require from sdt-devel to systemtap-headers again.
* Thu Feb  8 2018 matz@suse.com
- Don't include the headers files in sdt-devel
- Add systemtap-headers to Requires of sdt-devel, so that it
  provides the same files as before.  [fate#324969]
* Mon Nov 20 2017 tonyj@suse.com
- Upgrade to version 3.2
  Changelog: https://sourceware.org/ml/systemtap/2017-q4/msg00096.html
  Drop patch: systemtap-tweak-i386-argument-passing.patch (upstream)
  Update keyring.
- Fix issue with Kbuild handling of escaped paths (bsc#1067437)
  Add patch: systemtap-change-extra_cflags-escape-processing.patch
* Fri Nov 10 2017 mpluskal@suse.com
- Use pytho3 by default (fate#323526)
  * Do not explicitly require python by subpackage, dependency gets
    generated automatically
* Thu Mar 30 2017 tonyj@suse.com
- Tweak i386 argument-passing (bsc#1030285)
  New patch: systemtap-tweak-i386-argument-passing.patch
* Tue Mar 28 2017 jeffm@suse.com
- Update to version 3.1
  Update keyring with new key
  Changelog:
  https://sourceware.org/ml/systemtap/2017-q1/msg00106.html
* Fri Apr  1 2016 tonyj@suse.de
- Update to version 3.0
  Update keyring with new key
  Update info in README-KEYRING
  Changelog:
  https://sourceware.org/ml/systemtap/2016-q1/msg00179.html
* Tue Nov 10 2015 tonyj@suse.com
- Update to version 2.9.
  Update keyring with new key
  Changelog:
  https://sourceware.org/ml/systemtap/2015-q4/msg00025.html
* Fri Sep 11 2015 tonyj@suse.com
- Update to version 2.8.
  Update keyring with new key
  New file: README-KEYRING documenting how to update keyring
  Changelog:
  https://sourceware.org/ml/systemtap/2015-q2/msg00160.html
* Fri Mar 27 2015 mpluskal@suse.com
- Update keyring with new key
* Fri Mar 27 2015 p.drouand@gmail.com
- Update to version 2.7
  Changelog:
  https://sourceware.org/ml/systemtap/2015-q1/msg00173.html
- Update systemtap-docdir-fix.diff
* Tue Feb 17 2015 mpluskal@suse.com
- Add keyring and signature
- Cleanup spec file with spec-cleaner
* Tue Sep  9 2014 tonyj@suse.com
- Update to version 2.6
  Changelog:
    2.6: https://sourceware.org/ml/systemtap/2014-q3/msg00231.html
* Sat May 17 2014 coolo@suse.com
- use %%_rundir if available
* Fri May  2 2014 tonyj@suse.com
- Update to version 2.5
  Changelog:
    2.5: https://sourceware.org/ml/systemtap/2014-q2/msg00103.html
* Fri Nov 15 2013 tonyj@suse.com
- Update to version 2.4
  Changelog:
    2.4: http://sourceware.org/ml/systemtap/2013-q4/msg00165.html
* Wed Aug  7 2013 tonyj@suse.com
- Update to version 2.3
  Changelog:
    2.3: http://sourceware.org/ml/systemtap/2013-q3/msg00062.html
- Refresh systemtap-build-source-dir.patch for context
* Wed May 22 2013 tonyj@suse.com
- Upgrade to version 2.2.1
  Drop patch: systemtap-fix-for-kernels-without-vm_executable.patch
  Refresh patch (context): systemtap-build-source-dir.patch
  Changelog:
    2.1: http://sourceware.org/ml/systemtap/2013-q1/msg00130.html
    2.2.1: http://sourceware.org/ml/systemtap/2013-q2/msg00138.html
* Fri Feb 22 2013 tonyj@suse.com
- Change how systemtap looks for tracepoint header files
  (bnc#796574, new patch: systemtap-build-source-dir.patch)
- Add libebl1 dependancy. Systemtap manually loads libebl backends and
  the manual Requires: was incorrectly removed in a previous revision
  (bnc#800335)
* Fri Dec 14 2012 tonyj@suse.com
- Update to version 2.0
  Changelog: http://sourceware.org/ml/systemtap/2012-q4/msg00047.html
- Delete previous patches (present in version 2.0):
  link-with-pthread.patch
  systemtap-linux-types.patch
- Add patches:
  systemtap-fix-for-kernels-without-vm_executable.patch
* Wed Oct 17 2012 fcrozat@suse.com
- Fix build with new systemd location.
* Fri Jul 27 2012 aj@suse.de
- Fix build with glibc 2.16
* Mon Jun 18 2012 jslaby@suse.de
- Upgrade to version 1.8
  Changelog: http://sourceware.org/ml/systemtap/2012-q2/msg00277.html
* Sat Feb 18 2012 tonyj@suse.com
- Upgrade to version 1.7
  Changelog: http://sourceware.org/ml/systemtap/2012-q1/msg00097.html
* Wed Nov 23 2011 aj@suse.de
- Create tmpfiles during new install.
* Wed Nov  2 2011 jslaby@suse.de
- update to 1.6
  changes 1.5-1.6: http://sourceware.org/ml/systemtap/2011-q3/msg00105.html
  changes 1.4-1.5: http://sourceware.org/ml/systemtap/2011-q2/msg00218.html
* Fri Aug 19 2011 tonyj@novell.com
- Fix for bnc#710291 - systemtap: fails rpmlint check non-ghost-in-var-run
* Mon May  2 2011 idoenmez@novell.com
- Add systemtap-1.4-gcc46.patch to fix compilation with gcc 4.6
* Tue Mar 15 2011 jslaby@suse.de
- add ifdef CLONE_STOPPED to fix compilation on newer kernels
* Fri Jan 21 2011 tonyj@novell.com
- Update to version 1.4
  Changes in this release: https://lkml.org/lkml/2011/1/17/101
  Drop patches:
  systemtap-hppa.diff
  systemtap-support-2.6.36.diff
  systemtap_fix_mod_vs_del_timer_race.patch
  systemtap_improve_gettimeofday_stability.patch
* Fri Jan 14 2011 trenn@novell.com
- Hopefully fix bnc#664105:
  Kernel segfault in kernel/timer.c - comm: stapio (process) - related to preloadtrace.ko
* Mon Sep 13 2010 coolo@novell.com
- take fix for pr11940 from systemtap git
* Sun Sep  5 2010 bg@novell.com
- fix build for hppa
* Thu Aug 26 2010 tonyj@novell.com
- Update from version 1.1 to version 1.3
  Upstream release notes:
  1.3: http://sourceware.org/ml/systemtap/2010-q3/msg00098.html
  1.2: http://sourceware.org/ml/systemtap/2010-q1/msg00740.html
* Wed Jul 21 2010 vuntz@opensuse.org
- Add python Requires to sdt-devel subpackage since dtrace is a
  python script.
* Thu Mar 11 2010 tonyj@novell.com
- Add dependancies for systemtap shell scripts (coreutils, zip, avahi)
* Thu Mar 11 2010 tonyj@novell.com
- Update to version 1.1
- Fixes for CVE-2009-4273 (second part, also known as CVE-2010-0412) and
  CVE-2010-0411.
- Fix parsing error (systemtap-prevent-nested-arg.diff)
* Wed Dec  2 2009 tonyj@novell.com
- Fixes for CVE-2009-2911, BNC#548361
* Fri Oct  2 2009 tonyj@suse.de
- updated to version 1.0:
  * SystemTap frontend (stap) changes
  - EXPERIMENTAL support for unprivileged users.
  - -a ARCH allows cross compiling of scripts, stap-start-server arguments
    extended to support starting a cross compiling server
  - Change notion of architecture to be same as kernels
  - Support output file switching by SIGUSR2
  - New experimental transport mechanism using ftrace's ring_buffer
  - Reduction in memory consumption for scripts using many uprobes
  - Support for recognizing DW_OP_{stack,implicit}_value DWARF expressions
  * SystemTap script language changes
  - Dwarf probes now support C++ scopes and so can be limited to classes or
    namespaces.
  - Preprocessor support for || and &&
  - Probe alias names may be overloaded (multiple aliases of same name)
  * SystemTap tapset changes
  - Enabling semaphore now used to reduce computation overhead of dorman
    process().mark() probes.
  - Many functions marked as usable by unprivileged users (return global info
    or specific to user process).
  - New netdev tapset probe points for monitoring network traffic and device
    configurations.
  - New task_backtrace function returns the current hex backtrace of any
    arbitrary task in the system.
  - Function is_myproc returns whether the current process is owned by user
    which started systemtap script.
* Thu Aug 13 2009 tiwai@suse.de
- updated to version 0.9.9:
  * Systemwide kernel .function.return (kretprobe) maxactive overridden
  with -DKRETACTIVE=nnn parameter.
  * performance improvement in translation pass 2
  * new DW_OP_call_frame_CFA handling with elfutils 0.142
  * dwarf probes now show parameters and local variables in the verbose
  listing mode (-L)
  * symbol aliases are now resolved to their canonical dwarf names
  * The syntax for dereferencing $target variables and @cast() gained new
  capabilities
  * For reading all probe variables, kernel.mark now supports $$vars and
  $$parms, and process.syscall now supports $$vars.
  * SNMP tapset for many network statistics
  * dentry tapset to map kernel VFS directory entries to file or full
  path names: d_path(), d_name() and reverse_path_walk().
  * SystemTap now has userspace markers in its own binaries
  * More to see in NEWS
* Tue Jul 21 2009 tiwai@suse.de
- corrected to use libexecdir
- fix summary and description
* Tue Jun 16 2009 tiwai@suse.de
- updated to version 0.9.8:
  * Module signing support
  * Debuginfo suggestions when a script fails
  * Using %%M in print formats for hex dumps can now print entire
    buffers
  * Dwarfless syscalls: The nd_syscalls tapset is now available to
    probe system calls without requiring kernel debug info.
  * sid() returns the session ID of the current process
  * stringat() indexes a single character from a string.
  * New script examples
* Wed May 20 2009 tiwai@suse.de
- split docs and examples to docs subpackage and generate from its
  own spec file to cut off the dependency loop
* Fri May 15 2009 tiwai@suse.de
- split to several subpackages, systemtap-runtime, -client, -server
  and -sdt-devel (bnc#503088).
* Fri May  8 2009 tiwai@suse.de
- updated to released version 0.9.7:
  * Lots of fixes, improvements, see NEWS file for details
* Thu Feb 19 2009 tiwai@suse.de
- updated to systemtap snashot 20090214:
  * Version bump to 0.8
  * Bunch of fixes and updates, see ChangeLog
  * Fix for recent 2.6.29 kernels
- fixed doc build, using fop instead of direct xmlto pdf
* Thu Feb 12 2009 tiwai@suse.de
- backport the blacklist additions from upstream to fix possible
  system crash (bnc#459387, bnc#473277)
* Thu Feb  5 2009 tiwai@suse.de
- Backport tapset/signal.stp to fix the signal probe problem
  (bnc#468321)
* Tue Feb  3 2009 tiwai@suse.de
- Fix debugpath.exp with $SYSTEMTAP_DEBUGINFO_PATH (bnc#471811)
* Thu Jan 29 2009 tiwai@suse.de
- Fix procfs dir_entry count warning (bnc#470526)
- Improve the parsing of lineno checks (bnc#468247)
* Thu Jan 15 2009 tiwai@suse.de
- Fix quoting in Tcl scripts (bnc#461588)
* Mon Jan 12 2009 tiwai@suse.de
- Fix syntax errors with Tcl send_log (bnc#460886)
* Thu Dec 18 2008 tiwai@suse.de
- Fix stap failures with signal tapsets (bnc#459387)
* Tue Dec 16 2008 tiwai@suse.de
- Fix dependency on libebl1 (bnc#448331, #445783)
- Fix stap for 2.6.28 kernels
* Fri Dec 12 2008 tiwai@suse.de
- Don't assert of dwarf_getsrcfiles().  This hits recent SUSE
  kernels (bnc#455992)
- Backport fix patches for stap-*-server scripts to run with
  netcat (bnc#446686)
* Mon Dec  8 2008 tiwai@suse.de
- fixed unresolved path in man pages (bnc#457217)
- fixed build for old distros on OBS
* Thu Dec  4 2008 tiwai@suse.de
- fix ioblock.stp for SUSE 2.6.27.x kernel (bnc#456175)
* Fri Nov 21 2008 tiwai@suse.de
- Add the bound check of parameters to fix segfault (bnc#447551)
* Tue Nov  4 2008 tiwai@suse.de
- Fix systemtap assertion with CONFIG_RELOCATABLE (bnc#440351)
* Thu Sep 11 2008 tiwai@suse.de
- updated to snapshot 20080906
  * Fix / clean up autotools stuff
  * Ugly workaround for 2.6.27 and later kernel
  * stap-server updates
  * Lots of small fixes
* Tue Aug 12 2008 tiwai@suse.de
- updated to snapshot 20080809
  * bump to 0.7.1
  * tutorials
  * examples
  * i386-fix merged
  * previous patches are all merged in
- add latex2html to buildrequires for generating documents
* Fri Jun 20 2008 tiwai@suse.de
- fix run on i386 (bnc#401970)
- don't include obsolete linux/compile.h.
* Wed Jun 18 2008 tiwai@suse.de
- updated to snapshot 20080614:
  * bump to version 0.7, man page updates, misc fixes
    see ChangeLog for details
* Fri Mar 14 2008 tiwai@suse.de
- updated to snapshot 20080308:
  * configure fixes, compile option changes
  * fixes for 2.6.25 kernel
* Wed Jan 30 2008 tiwai@suse.de
- updated to snapshot 20080126
  * fix configure and automake stuff
  * gcc 4.3 fix is included
  * ufprobes fixes, improvements
  * reorganized probe condition implementation.
* Fri Jan 11 2008 tiwai@suse.de
- updated to snapshot 20080105
- fixed build of the snapshot with gcc 4.3
* Mon Nov 19 2007 tiwai@suse.de
- enable gcc-4.3 patch (yes, we use only gcc4.3 now)
- updated to snapshot 20071117
* Thu Oct 25 2007 tiwai@suse.de
- disable gcc-4.3 fix again since it breaks older gccs...
* Wed Oct 24 2007 tiwai@suse.de
- fix build with gcc 4.3
* Mon Oct 22 2007 tiwai@suse.de
- updated to snapshot 20071020:
  * bump up version 0.6
  * bunch of updates and fixes, see ChangeLog
* Tue Aug 14 2007 tiwai@suse.de
- updated to snapshot 20070811:
  * Updated -m MODNAME usage
  * Rework on line editing functions
* Mon Jul 16 2007 tiwai@suse.de
- updated to snapshot 20070714:
  * configure fix for sqlite
  * support for crash extension module
  * new enum for type column in coverage_element
* Wed Jul  4 2007 tiwai@suse.de
- updated to snapshot 20070630:
  * auto-tools fixes, sqlite3 requirement
- add sqlite-devel and glib2-devel to buildrequires
* Wed Jun  6 2007 tiwai@suse.de
- updated to snapshot 20070602:
  * fix for gcc4.3
  * minor fixes in elaborate.*
- include the snapshot date into version string
- clean up spec file
* Tue May 22 2007 tiwai@suse.de
- updated to snapshot 20070519:
  * Updated temporary handlings
  * Autoconf tweaks
  * Performance improvements with const and temporary handlings
  * Removed do_write and do_read probles, added aio_write,
    aio_read, writev and readv probes.
* Mon May 21 2007 tiwai@suse.de
- use the external elfutils packages.
* Tue Apr 24 2007 tiwai@suse.de
- updated to snapshot 20070421 and elfutils-0.127:
  * minor compile warning fixes
  * add interruptible parameter
  * improvement on documents
  * fix for debugfs and relayfs mounts
  * see ChangeLog for other changes
* Mon Mar 19 2007 tiwai@suse.de
- updated to snapshot 20070317:
  including all fix patches
* Thu Mar  8 2007 tiwai@suse.de
- fix the handling of function arguments in more generic way
  (#245310, #252311)
  added a new option -P to switch the prologue-search behavior
* Wed Mar  7 2007 tiwai@suse.de
- fix misalignment of exception table entry on s390x (#249576)
* Mon Feb 26 2007 tiwai@suse.de
- fix crash with large H value in hist_linear() (#248430)
* Fri Feb 23 2007 tiwai@suse.de
- fix mmap syscall on s390x (#248110)
* Thu Feb 15 2007 tiwai@suse.de
- fix a wrong name of store_deref definition (#245544)
* Wed Feb 14 2007 tiwai@suse.de
- fix the handling of function arguments on s390x (#245310)
* Tue Feb  6 2007 tiwai@suse.de
- update to snapshot 20070203, bugfixes including:
  * add missing sockets tapset support (#239346)
  * fix the array membership (#242481)
* Wed Jan 31 2007 tiwai@suse.de
- turn on Autoprov again to fix broken dependency.
* Tue Jan 30 2007 tiwai@suse.de
- update to snapshot 20070120 and elfutils-0.125 to fix major
  bugs (#238710):
  * fixed libdw known bugs in elfutils 0.124
  * add the missing support of tapsetr/errno.stp for s390x
  * fix conditionals in syscall tapset for s390x
  * new macros to safely read/write values from kernel pointers
  * fix the non-standard C behavior to handle NULL in an array
  * fixed support for benchmarking mode with off-line code
  * added support to allow user to use array size declarations
  * reduce number of calls to stp_module_relocate within $tvar
    functions
* Tue Jan  9 2007 tiwai@suse.de
- updated to the recent snapshot version (FATE 301670).
  * fix cache bugs
  * auto-tools fixes
  * probe registartion rework
  * allow negative numeric literals
  * bugfixes/optmizations
- elfutls 1.2.4
  removed codes with problematic license in elfutils (#232894)
* Thu Aug 24 2006 tiwai@suse.de
- update elfutils to 1.2.3, including vmlinux.debuginfo fix.
* Thu Aug 24 2006 tiwai@suse.de
- fix the auto-lookup of vmlinux debuginfo for SUSE systems
- fix the stp compilation with 2.6.18 kernel
* Wed Aug  9 2006 tiwai@suse.de
- updated to latest snapshot (version 0.5.8)
  with elfutils-1.2.2.
* Tue Apr 18 2006 mason@suse.de
- Update to latest snapshot
* Sun Apr  9 2006 mason@suse.de
- created package
